@@ -12,12 +12,7 @@ use strict;
 use warnings;
 
 use constant NAME => 'BmpConvert';
-use constant REQUIRED_MODULES => [
-  {
-      package => 'PerlMagick',
-      module  => 'Image::Magick',
-      version => 0,
-  },
-];
+use constant REQUIRED_MODULES =>
+  [{package => 'PerlMagick', module => 'Image::Magick', version => 0,},];
 
 __PACKAGE__->NAME;
